@@ -587,7 +587,7 @@ class Processing:
                         
                         # For OF algorithms, get OB base object
                         OF_base = self._processing_data.get_OF_base(channel,
-                                                                    base_algorithm)
+                                                                    algorithm)
                         if OF_base is not None:
                             extracted_features = extractor(OF_base, **kwargs)
                         else:
